<?php

/**
 * ClassLoader.
 *
 * @author Katsuhiro Ogawa <fivestar@nequal.jp>
 */
class ClassLoader
{
    protected $dirs = [];

    /**
     * Register the ClassLoader instance as an autoloader on the SPL autoload stack
     */
    public function register(): void
    {
        spl_autoload_register([$this, 'loadClass']);
    }

    /**
     * Register a directory to be searched for classes
     *
     * @param string $dir
     */
    public function registerDir(string $dir): void
    {
        $this->dirs[] = $dir;
    }

    /**
     * Load a class
     *
     * @param string $class The fully-qualified class name
     */
    public function loadClass(string $class): void
    {
        foreach ($this->dirs as $dir) {
            $file = $dir . '/' . str_replace('\\', '/', $class) . '.php';
            if (is_readable($file)) {
                require $file;
                return;
            }
        }
    }
}
