<?php

/**
 * DbRepository.
 *
 * @author Katsuhiro Ogawa <fivestar@nequal.jp>
 */
abstract class DbRepository
{
    protected $con;

    /**
     * Constructor.
     *
     * @param PDO $con
     */
    public function __construct(PDO $con)
    {
        $this->setConnection($con);
    }

    /**
     * Sets the database connection.
     *
     * @param PDO $con
     */
    public function setConnection(PDO $con)
    {
        $this->con = $con;
    }

    /**
     * Executes a SQL query with the specified parameters.
     *
     * @param string $sql
     * @param array $params
     * @return PDOStatement
     */
    public function execute(string $sql, array $params = []): PDOStatement
    {
        $stmt = $this->con->prepare($sql);
        $stmt->execute($params);

        return $stmt;
    }

    /**
     * Executes a SQL query and fetches the first row of the result set.
     *
     * @param string $sql
     * @param array $params
     * @return mixed
     */
    public function fetch(string $sql, array $params = [])
    {
        $stmt = $this->execute($sql, $params);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    /**
     * Executes a SQL query and fetches all rows of the result set.
     *
     * @param string $sql
     * @param array $params
     * @return array
     */
    public function fetchAll(string $sql, array $params = []): array
    {
        $stmt = $this->execute($sql, $params);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
}



