
<php
/**
 * Request.
 *
 * @author Katsuhiro Ogawa <fivestar@nequal.jp>
 */
class Request
{
    /**
     * Determines whether the request method is POST.
     *
     * @return bool
     */
    public function isPost()
    {
        return ($_SERVER['REQUEST_METHOD'] === 'POST');
    }

    /**
     * Gets a GET parameter by name.
     *
     * @param string $name
     * @param mixed $default The default value if the key is not found.
     * @return mixed
     */
    public function getGet($name, $default = null)
    {
        return $_GET[$name] ?? $default;
    }

    /**
     * Gets a POST parameter by name.
     *
     * @param string $name
     * @param mixed $default The default value if the key is not found.
     * @return mixed
     */
    public function getPost($name, $default = null)
    {
        return $_POST[$name] ?? $default;
    }

    /**
     * Gets the host name.
     *
     * @return string
     */
    public function getHost()
    {
        return $_SERVER['HTTP_HOST'] ?? $_SERVER['SERVER_NAME'];
    }

    /**
     * Determines whether the request is made over SSL.
     *
     * @return bool
     */
    public function isSsl()
    {
        return isset($_SERVER['HTTPS']) && ($_SERVER['HTTPS'] === 'on');
    }

    /**
     * Gets the request URI.
     *
     * @return string
     */
    public function getRequestUri()
    {
        return $_SERVER['REQUEST_URI'];
    }

    /**
     * Gets the base URL.
     *
     * @return string
     */
    public function getBaseUrl()
    {
        $script_name = $_SERVER['SCRIPT_NAME'];
        $request_uri = $this->getRequestUri();

        if (strpos($request_uri, '?') !== false) {
            $request_uri = substr($request_uri, 0, strpos($request_uri, '?'));
        }

        $path = substr($request_uri, strlen(dirname($script_name)));
        return rtrim(dirname($script_name), '/') . $path;
    }

    /**
     * Gets the PATH_INFO.
     *
     * @return string
     */
    public function getPathInfo()
    {
        $base_url = $this->getBaseUrl();
        $request_uri = $this->getRequestUri();

        if (strpos($request_uri, '?') !== false) {
            $request_uri = substr($request_uri, 0, strpos($request_uri, '?'));
        }

        return (string) substr($request_uri, strlen($base_url));
    }
}