<?php

/**
 * Router.
 *
 * @author Katsuhiro Ogawa
 */
class Router
{
    protected $routes;

    /**
     * Constructor.
     *
     * @param array $definitions
     */
    public function __construct(array $definitions)
    {
        $this->routes = $this->compileRoutes($definitions);
    }

    /**
     * Compiles the routes to a format suitable for matching.
     *
     * @param array $definitions
     * @return array
     */
    public function compileRoutes(array $definitions)
    {
        $routes = [];

        foreach ($definitions as $url => $params) {
            $tokens = explode('/', ltrim($url, '/'));
            foreach ($tokens as $i => $token) {
                if (0 === strpos($token, ':')) {
                    $name = substr($token, 1);
                    $token = "(?P<$name>[^/]+)";
                }
                $tokens[$i] = $token;
            }

            $pattern = '/' . implode('/', $tokens);
            $routes[$pattern] = $params;
        }

        return $routes;
    }

    /**
     * Resolves the routing parameters for a given path.
     *
     * @param string $pathInfo
     * @return array|false
     */
    public function resolve($pathInfo)
    {
        if ('/' !== substr($pathInfo, 0, 1)) {
            $pathInfo = '/' . $pathInfo;
        }

        foreach ($this->routes as $pattern => $params) {
            if (preg_match('#^' . $pattern . '$#', $pathInfo, $matches)) {
                $params = array_merge($params, $matches);

                return $params;
            }
        }

        return false;
    }
}